package
    YA::CLI::Example;
use Moo;

extends 'YA::CLI';


__PACKAGE__->meta->make_immutable;

__END__

=head1 DESCRIPTION

=head1 SYNOPSIS

    use Foo;

